@@ -1,9 +1,16 @@
 # -*- coding: utf-8 -*-
+"""
+    celery.backends.cache
+    ~~~~~~~~~~~~~~~~~~~~~
+
+    Memcache and in-memory cache result backend.
+
+"""
 from __future__ import absolute_import
 
-from ..datastructures import LRUCache
-from ..exceptions import ImproperlyConfigured
-from ..utils import cached_property
+from celery.datastructures import LRUCache
+from celery.exceptions import ImproperlyConfigured
+from celery.utils import cached_property
 
 from .base import KeyValueStoreBackend
 
@@ -21,14 +28,14 @@ def import_best_memcache():
                 import memcache  # noqa
             except ImportError:
                 raise ImproperlyConfigured(
-                        "Memcached backend requires either the 'pylibmc' "
-                        "or 'memcache' library")
+                    'Memcached backend requires either the pylibmc '
+                    'or memcache library')
         _imp[0] = (is_pylibmc, memcache)
     return _imp[0]
 
 
 def get_best_memcache(*args, **kwargs):
-    behaviors = kwargs.pop("behaviors", None)
+    behaviors = kwargs.pop('behaviors', None)
     is_pylibmc, memcache = import_best_memcache()
     client = memcache.Client(*args, **kwargs)
     if is_pylibmc and behaviors is not None:
@@ -58,15 +65,16 @@ class DummyClient(object):
         return self.cache.incr(key, delta)
 
 
-backends = {"memcache": lambda: get_best_memcache,
-            "memcached": lambda: get_best_memcache,
-            "pylibmc": lambda: get_best_memcache,
-            "memory": lambda: DummyClient}
+backends = {'memcache': lambda: get_best_memcache,
+            'memcached': lambda: get_best_memcache,
+            'pylibmc': lambda: get_best_memcache,
+            'memory': lambda: DummyClient}
 
 
 class CacheBackend(KeyValueStoreBackend):
     servers = None
     supports_native_join = True
+    implements_incr = True
 
     def __init__(self, expires=None, backend=None, options={}, **kwargs):
         super(CacheBackend, self).__init__(self, **kwargs)
@@ -76,16 +84,16 @@ class CacheBackend(KeyValueStoreBackend):
 
         self.backend = backend or self.app.conf.CELERY_CACHE_BACKEND
         if self.backend:
-            self.backend, _, servers = self.backend.partition("://")
-            self.servers = servers.rstrip('/').split(";")
+            self.backend, _, servers = self.backend.partition('://')
+            self.servers = servers.rstrip('/').split(';')
         self.expires = self.prepare_expires(expires, type=int)
         try:
             self.Client = backends[self.backend]()
         except KeyError:
             raise ImproperlyConfigured(
-                    "Unknown cache backend: %s. Please use one of the "
-                    "following backends: %s" % (self.backend,
-                                                ", ".join(backends.keys())))
+                    'Unknown cache backend: %s. Please use one of the '
+                    'following backends: %s' % (self.backend,
+                                                ', '.join(backends.keys())))
 
     def get(self, key):
         return self.client.get(key)
@@ -99,30 +107,19 @@ class CacheBackend(KeyValueStoreBackend):
     def delete(self, key):
         return self.client.delete(key)
 
-    def on_chord_apply(self, setid, body, result=None, **kwargs):
-        key = self.get_key_for_chord(setid)
-        self.client.set(key, '0', time=86400)
+    def on_chord_apply(self, group_id, body, result=None, **kwargs):
+        self.client.set(self.get_key_for_chord(group_id), '0', time=86400)
 
-    def on_chord_part_return(self, task, propagate=False):
-        from ..task.sets import subtask
-        from ..result import TaskSetResult
-        setid = task.request.taskset
-        if not setid:
-            return
-        key = self.get_key_for_chord(setid)
-        deps = TaskSetResult.restore(setid, backend=task.backend)
-        if self.client.incr(key) >= deps.total:
-            subtask(task.request.chord).delay(deps.join(propagate=propagate))
-            deps.delete()
-            self.client.delete(key)
+    def incr(self, key):
+        return self.client.incr(key)
 
     @cached_property
     def client(self):
         return self.Client(self.servers, **self.options)
 
     def __reduce__(self, args=(), kwargs={}):
-        servers = ";".join(self.servers)
-        backend = "%s://%s/" % (self.backend, servers)
+        servers = ';'.join(self.servers)
+        backend = '%s://%s/' % (self.backend, servers)
         kwargs.update(
             dict(backend=backend,
                  expires=self.expires,
