@@ -126,12 +126,7 @@ class Request(object):
         else:
             self.expires = None
 
-        delivery_info = {} if delivery_info is None else delivery_info
-        self.delivery_info = {
-            'exchange': delivery_info.get('exchange'),
-            'routing_key': delivery_info.get('routing_key'),
-        }
-
+        self.delivery_info = delivery_info or {}
         self.request_dict = body
 
     @classmethod
